===============
Sample Document
===============

Renders a go diagram.  This will take an ascii go diagram and return
an image node which points to the new image
   
Looks like:
  
.. go:: go_diagrams/output.png

    $$ -----------
    $$ | . X . 
    $$ | O X a 
    $$ | 1 2 . 
    $$ | . . 0 

The stone marked "1" should be white and the stone marked "2" should be 
black.
